@@ -52,7 +52,7 @@ assumptions about how things will work.
 
 """
 
-from pylons import app_globals, request, response, tmpl_context, session, cache
+from pylons import app_globals, request, response, tmpl_context, session, cache, translator
 
 from tg.wsgiapp import TGApp
 from tg.controllers import TGController, redirect, url, lurl, abort
@@ -64,10 +64,12 @@ from tg.decorators import (validate, expose, override_template,
 from tg.flash import flash, get_flash, get_status
 from tg.jsonify import encode as json_encode
 from tg.controllers.util import use_wsgi_app
+from tg.controllers.dispatcher import dispatched_controller
 
 __version__ = version
 
 __all__ = ['__version__',
     'allow_only', 'app_globals', 'expose', 'override_template', 'request',
     'require', 'response', 'session', 'TGApp', 'TGController', 'tmpl_context',
-    'use_wsgi_app', 'validate', 'i18n','json_encode', 'cache', 'url', 'lurl']
+    'use_wsgi_app', 'validate', 'i18n','json_encode', 'cache', 'url', 'lurl',
+    'dispatched_controller']
