@@ -15,18 +15,23 @@ This module also contains the standard ObjectDispatch
 class which provides the ordinary TurboGears mechanism.
 
 """
-from urllib import url2pathname
 from inspect import ismethod, isclass, getargspec
 from warnings import warn
-import pylons
+import pylons, sys
 import mimetypes
 from pylons.controllers import WSGIController
 from tg.exceptions import HTTPNotFound
 from tg.i18n import setup_i18n
-from tg.util import odict
+from tg.decorators import cached_property
 
 HTTPNotFound = HTTPNotFound().exception
 
+def dispatched_controller():
+    state = pylons.request.controller_state
+    for location, cont in reversed(state.controller_path):
+        if cont.mount_point:
+            return cont
+    return None
 
 class DispatchState(object):
     """
@@ -37,7 +42,7 @@ class DispatchState(object):
     """
     def __init__(self, url_path, params):
         self.url_path = url_path
-        self.controller_path = odict()
+        self.controller_path = []
         self.routing_args = {}
         self.method = None
         self.remainder = None
@@ -53,7 +58,7 @@ class DispatchState(object):
 
     def add_controller(self, location, controller):
         """Add a controller object to the stack"""
-        self.controller_path[location] = controller
+        self.controller_path.append((location, controller))
 
     def add_method(self, method, remainder):
         """Add the final method that will be called in the _call method"""
@@ -77,7 +82,7 @@ class DispatchState(object):
     @property
     def controller(self):
         """returns the current controller"""
-        return self.controller_path.getitem(-1)
+        return self.controller_path[-1][1]
 
 
 class Dispatcher(WSGIController):
@@ -406,6 +411,7 @@ class ObjectDispatcher(Dispatcher):
             obj = getattr(controller, 'im_self', controller)
             if hasattr(obj, '_check_security'):
                 obj._check_security()
+
             state.add_controller(current_path, controller)
             state.dispatcher = controller
             return controller._dispatch(state, remainder)
@@ -456,20 +462,21 @@ class ObjectDispatcher(Dispatcher):
             return self._dispatch_first_found_default_or_lookup(state, remainder)
 
         current_path = remainder[0]
+        current_args = remainder[1:]
 
         #an exposed method matching the path is found
         if self._is_exposed(current_controller, current_path):
             #check to see if the argspec jives
             controller = getattr(current_controller, current_path)
-            if self._method_matches_args(controller, state, remainder[1:]):
-                state.add_method(controller, remainder[1:])
+            if self._method_matches_args(controller, state, current_args):
+                state.add_method(controller, current_args)
                 return state
 
         #another controller is found
         if hasattr(current_controller, current_path):
             current_controller = getattr(current_controller, current_path)
             return self._dispatch_controller(
-                current_path, current_controller, state, remainder[1:])
+                current_path, current_controller, state, current_args)
 
         #dispatch not found
         return self._dispatch_first_found_default_or_lookup(state, remainder)
@@ -498,3 +505,25 @@ class ObjectDispatcher(Dispatcher):
         This is expected to be overridden by any subclass that wants to set
         the routing_args (RestController). Do not delete.
         """
+
+    @cached_property
+    def mount_point(self):
+        if not self.mount_steps:
+            return ''
+        return '/' + '/'.join((x[0] for x in self.mount_steps[1:]))
+
+    @cached_property
+    def mount_steps(self):
+        def find_url(root, item, parents):
+            for i in root.__dict__:
+                controller = root.__dict__[i]
+                if controller is item:
+                    return parents + [(i, item)]
+                if hasattr(controller, '_dispatch'):
+                    v = find_url(controller.__class__, item, parents + [(i, controller)])
+                    if v:
+                        return v
+            return []
+
+        root_controller = sys.modules[pylons.config['application_root_module']].RootController
+        return find_url(root_controller, self, [('/', root_controller)])
